@@ -1,10 +1,18 @@
-import docker
-from io import BytesIO
-from mtlibs import tar_helper
+import os
 import tarfile
+from io import BytesIO
 from pathlib import Path
+# import docker
+import tar_helper
 
 
+def isInContainer():
+    return os.path.exists("/.dockerenv")
+
+def is_docker():
+    cgroup = Path("/proc/self/cgroup")
+    return Path('/.dockerenv').is_file() or cgroup.is_file() and cgroup.read_text().find("docker") > -1
+
 def copy_dir(container, local_dir, container_dir):
     """ 将本地文件或文件夹打包复制到容器内
         : container 容器实例
